@@ -19,12 +19,12 @@
 
 #include "avogadrocoreexport.h"
 
-#define AvogadroLibs_VERSION "1.99.0"
+#define AvogadroLibs_VERSION "1.101.0"
 
 namespace Avogadro {
 
-AVOGADROCORE_EXPORT const char *version();
+AVOGADROCORE_EXPORT const char* version();
 
-} // end Avogadro namespace
+} // namespace Avogadro
 
 #endif /* VERSION_H_ */
